AuthOptions class abstract

Available extensions

Constructors

AuthOptions({Map<String, dynamic> params, Map<String, dynamic> headers})
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
headers ↔ Map<String, dynamic>
getter/setter pair
params ↔ Map<String, dynamic>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>

Available on AuthOptions, provided by the AuthOptionsExt extension

toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited