ConnectionManagerOptions class abstract

Constructors

ConnectionManagerOptions({Timeline timeline, Strategy getStrategy(dynamic), num unavailableTimeout, num pongTimeout, num activityTimeout, bool useTLS})
factory

Properties

activityTimeout ↔ num
getter/setter pair
getStrategy ↔ Strategy Function(dynamic)
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
pongTimeout ↔ num
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timeline ↔ Timeline
getter/setter pair
unavailableTimeout ↔ num
getter/setter pair
useTLS ↔ bool
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited