URLLocation class abstract

Constructors

URLLocation({String base, String queryString})
factory

Properties

base ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
queryString ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited