Timer class abstract

Implementers

Constructors

Timer(Scheduler set, Canceller clear, num delay, TimedCallback callback)
factory

Properties

clear ↔ Canceller
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timer ↔ dynamic
getter/setter pair

Methods

ensureAborted() → dynamic
Aborts a timer when it's running.
isRunning() → bool
Returns whether the timer is still running.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited