OneOffTimer class

Cross-browser compatible one-off timer abstraction.

Inheritance

Constructors

OneOffTimer(num delay, TimedCallback callback)
factory

Properties

clear ↔ Canceller
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timer ↔ dynamic
getter/setter pairinherited

Methods

ensureAborted() → dynamic
Aborts a timer when it's running.
inherited
isRunning() → bool
Returns whether the timer is still running.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited