clearTimeout function
dynamic
clearTimeout(
- dynamic timer
We need to bind clear functions this way to avoid exceptions on IE8
Implementation
@JS()
external clearTimeout(timer);
We need to bind clear functions this way to avoid exceptions on IE8
@JS()
external clearTimeout(timer);