buildLogSuffix top-level property
dynamic
get
buildLogSuffix
Builds a consistent string with links to pusher documentation
Implementation
@JS()
external get buildLogSuffix;
Builds a consistent string with links to pusher documentation
@JS()
external get buildLogSuffix;