ScriptReceiverFactory class

Builds receivers for JSONP and Script requests. Each receiver is an object with following fields:

  • number - unique (for the factory instance), numerical id of the receiver
  • id - a string ID that can be used in DOM attributes
  • name - name of the function triggering the receiver
  • callback - callback function Receivers are triggered only once, on the first callback call. Receivers can be called by their name or by accessing factory object by the number key.

Constructors

ScriptReceiverFactory(String prefix, String name)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
lastId num
getter/setter pair
name String
getter/setter pair
prefix String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

create(Function callback) ScriptReceiver
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(ScriptReceiver receiver) → dynamic
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited